@@ -71,9 +71,13 @@ class Run:
                 value.upload_file(self, key)
             elif isinstance(value, list):
                 if all(isinstance(n, Image) for n in value):    #Image 객체 배열일 경우
-                        data[key] = json.dumps([n.to_dict(key_name=key, is_list=True, index=index) for index, n in enumerate(value) ])
-                        for n in value:
-                            n.upload_file(self, key)
+                        list_dict = []
+                        for index, n in enumerate(value):
+                            list_dict.append(n.to_dict(key_name=key, is_list=True, index=index))
+                            n.upload_file(self, key, is_list=True, index=index)
+                        data[key] = json.dumps(list_dict)
+
+
                         logger.debug(f"Image 객체(배열)을 str(json)로 변환 변환 : {data[key]}")
 
 
