@@ -105,7 +105,7 @@ def login_required(original_function):
         from deepdriver.sdk.interface.interface import get_stub
         stub = get_stub()
         if not stub:
-            logger.info("please log in first")
+            logger.error("please log in first")
             raise Exception("Login required.")
         return original_function(*args, **kwargs)
 
@@ -120,7 +120,7 @@ def init_required(original_function):
         from deepdriver.sdk.data_types.run import get_run
         run = get_run()
         if not run:
-            logger.info("please call deepdriver.init() first")
+            logger.error("please call deepdriver.init() first")
             raise Exception("Deepdriver not inited")
         return original_function(*args, **kwargs)
 
